cmd

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConfigCommand

func ConfigCommand(args []string)

ConfigCommand displays the current gimi configuration settings. Usage: gimi config show or gimi config --show

func GenerateCommand

func GenerateCommand(cmd string, args []string)

func HistoryCommand

func HistoryCommand(args []string)

HistoryCommand displays recent git commits and lets the user select one to copy as a reusable git commit command. Usage: gimi history (default: last 10 commits)

gimi history -n 20 (show last 20 commits)

func InitCommand

func InitCommand(args []string)

func ResetCommand

func ResetCommand(args []string)

Types

This section is empty.

Jump to