Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigCommand ¶
func ConfigCommand(args []string)
ConfigCommand displays the current gimi configuration settings. Usage: gimi config show or gimi config --show
func GenerateCommand ¶
func HistoryCommand ¶
func HistoryCommand(args []string)
HistoryCommand displays recent git commits and lets the user select one to copy as a reusable git commit command. Usage: gimi history (default: last 10 commits)
gimi history -n 20 (show last 20 commits)
func InitCommand ¶
func InitCommand(args []string)
func ResetCommand ¶
func ResetCommand(args []string)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.